summaryrefslogtreecommitdiff
path: root/bin/fuzz.pl
diff options
context:
space:
mode:
authorOssama Othman <ossama-othman@users.noreply.github.com>2004-05-02 05:35:41 +0000
committerOssama Othman <ossama-othman@users.noreply.github.com>2004-05-02 05:35:41 +0000
commit3f8d1c831ffa72dcc1298dfb134f32ac423f9778 (patch)
tree40ac65057b5e36931409159af41c5839a4d77ec7 /bin/fuzz.pl
parentf923db913bcfa43c097b18e2ab83756bd381656c (diff)
downloadATCD-3f8d1c831ffa72dcc1298dfb134f32ac423f9778.tar.gz
ChangeLogTag:Sat May 1 22:23:35 2004 Ossama Othman <ossama@dre.vanderbilt.edu>
Diffstat (limited to 'bin/fuzz.pl')
-rwxr-xr-xbin/fuzz.pl10
1 files changed, 5 insertions, 5 deletions
diff --git a/bin/fuzz.pl b/bin/fuzz.pl
index 17031943432..b60430e34d2 100755
--- a/bin/fuzz.pl
+++ b/bin/fuzz.pl
@@ -116,7 +116,7 @@ sub store_file ($)
elsif ($name =~ /ChangeLog/i && -f $name) {
push @files_changelog, ($name);
}
- elsif ($name =~ /\/Makefile.*.[^~]$/) {
+ elsif ($name =~ /\/GNUMakefile.*.[^~]$/) {
push @files_makefile, ($name);
}
elsif ($name =~ /\.(mpc|mwc|mpb|mpt)/i) {
@@ -530,7 +530,7 @@ sub check_for_dependency_file ()
if (/^DEPENDENCY_FILE\s* =\s*(.*)/) {
my $depend = $1;
my $path = $file;
- $path =~ s/\/Makefile.*/\//;
+ $path =~ s/\/GNUMakefile.*/\//;
$depend = $path . $depend;
unless (open (DFILE, $depend)) {
print_error ("DEPENDENCY_FILE \"$depend\" not found");
@@ -549,8 +549,8 @@ sub check_for_dependency_file ()
}
}
# This checks to see if Makefiles define a MAKEFILE, and if it matches the
# name of the Makefile
sub check_for_makefile_variable ()
{
print "Running MAKEFILE variable test\n";
@@ -573,7 +573,7 @@ sub check_for_makefile_variable ()
}
}
}
- if ($makevarfound == 0 and !($filename eq "Makefile")) {
+ if ($makevarfound == 0 and !($filename eq "GNUMakefile")) {
print_error ("MAKEFILE variable missing in $file");
print " Add MAKEFILE = $filename to the top of $file.\n\n";
}
@@ -549,8 +549,8 @@ sub check_for_dependency_file ()
}
}
-# This checks to see if Makefiles define a MAKEFILE, and if it matches the
-# name of the Makefile
+# This checks to see if GNUMakefiles define a MAKEFILE, and if it matches the
+# name of the GNUMakefile
sub check_for_makefile_variable ()
{